@@ -4,8 +4,11 @@ import json
 import pandas as pd
 import os
 from time import sleep
+import logging
 
-versionNo = "1.0.2"
+_logger = logging.getLogger(__name__)
+
+versionNo = "1.0.3"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -67,15 +70,15 @@ def sendControl(controlDict, showResult=1):
     if showResult==1:
         if returnMessage["resultCode"] != "ok":
             if returnMessage["resultCode"] == "invalidInput":
-                print("[INVALID INPUT]: ", returnMessage["message"], ":")
+                logging.error("[INVALID INPUT]: ", returnMessage["message"], ":")
                 for error in returnMessage["data"]["errors"]:
-                    print("    - ", error["parameter"],
+                    logging.error("    - ", error["parameter"],
                           error["$type"].split('.')[-1], error["description"])
             elif returnMessage["resultCode"] == "badRequest":
-                print("[BAD REQUEST]:",
+                logging.error("[BAD REQUEST]:",
                       controlString.decode('ascii'))
             elif returnMessage["resultCode"] == "invalidOperation":
-                print("[INVALID OPERATION]: ",
+                logging.error("[INVALID OPERATION]: ",
                       controlString.decode('ascii'))
     return returnMessage
 
@@ -91,7 +94,7 @@ def disconnect():
     if events.eventSock is not None:
         events.disconnect()
     sleep(1)
-    print("Disconnected from impulse")
+    logging.error("Disconnected from impulse")
 
 def getStatus():
     controlDict = {
@@ -103,12 +106,12 @@ def getStatus():
 
 def waitForControl():
     status = getStatus()
-    print("[IMPULSE STATUS]:", status)
+    logging.error("[IMPULSE STATUS]:", status)
     while status != "control": 
         sleep(0.2)
         newStatus = getStatus()
         if newStatus != status: 
-            print("[IMPULSE STATUS]:", newStatus)
+            logging.error("[IMPULSE STATUS]:", newStatus)
         status = newStatus
     sleep(1) # To prevent fatal errors
 
@@ -353,7 +356,7 @@ class eventHandler():
         self.eventCatcherThread.start()
 
     def eventCatcher(self):
-        print("\n Subscribed to impulse events. ")
+        logging.info("\n Subscribed to impulse events. ")
         while True:
             if self.event.is_set():
                 break
@@ -361,7 +364,7 @@ class eventHandler():
                 [address, contents] = self.eventSock.recv_multipart()
                 contents = json.loads(contents)
             except:
-                print("Multipart issue")
+                logging.error("Multipart issue")
                 continue
             else:   
                 self.lastMssg = contents
@@ -373,14 +376,14 @@ class eventHandler():
                     if contents["stimulusType"]=="gas":
                         gas.busy = False
                 elif contents["$type"] == "data.event.profileController.stateChanged": #deze moet ook anders heten
-                    print("[PROFILE CONTROLLER]:",contents['state'])
+                    logging.error("[PROFILE CONTROLLER]:",contents['state'])
                 elif contents["$type"] == "data.event.popupRaised":
-                    print("[IMPULSE POPUP]:",contents['message'])
+                    logging.error("[IMPULSE POPUP]:",contents['message'])
                 elif contents["$type"] == "data.event.notificationRaised":
-                    print("[IMPULSE NOTIFICATION]:",contents['message'])
+                    logging.error("[IMPULSE NOTIFICATION]:",contents['message'])
                     sleep(0.1)
                 else:
-                    print("[IMPULSE EVENT]:",contents)
+                    logging.error("[IMPULSE EVENT]:",contents)
         self.eventSock.setsockopt(zmq.LINGER, 0)
         self.eventSock.close()
         self.context.term()
@@ -439,7 +442,7 @@ class dataHandler():
         self.dataSock.setsockopt(zmq.SUBSCRIBE, btopic)
         self.dataThread = Thread(target=self.incomingDataReader)
         self.dataThread.start()
-        print(f"\n Subscribed to {self.topic} data. ")
+        logging.info(f"\n Subscribed to {self.topic} data. ")
 
     def incomingDataReader(self):
         if self.topic != "massSpec":
@@ -537,9 +540,9 @@ class dataHandler():
 
         else:
             if self.topic == 'massSpec':
-                print("[ALERT] Please subscribe using impulse.gas.msdata.subscribe() first")
+                logging.error("[ALERT] Please subscribe using impulse.gas.msdata.subscribe() first")
             else:
-                print(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
+                logging.error(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
             return []
 
     def getNewData(self):
@@ -558,7 +561,7 @@ class dataHandler():
                         dataSet[key]=round(dataSet[key],decimalVals[key])                       
             return dataSet
         else:
-            print(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
+            logging.error(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
             return []
         
     def setFlag(self, flagName):
@@ -566,7 +569,7 @@ class dataHandler():
             self.flags[flagName]=len(self.data)
             self.currentFlag = flagName
         else:
-            print(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
+            logging.error(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
             return []
 
     def getDataFrame(self, startRowOrFlag=1, endRowOrFlag=None):
@@ -575,13 +578,13 @@ class dataHandler():
                 if startRowOrFlag in self.flags:
                     startRowOrFlag= self.flags[startRowOrFlag]
                 else:
-                    print(f"[ERROR] Flag {startRowOrFlag} does not exist!")
+                    logging.error(f"[ERROR] Flag {startRowOrFlag} does not exist!")
                     return []
             if isinstance(endRowOrFlag, str):
                 if endRowOrFlag in self.flags:
                     endRowOrFlag= self.flags[endRowOrFlag]
                 else:
-                    print(f"[ERROR] Flag {endRowOrFlag} does not exist!")
+                    logging.error(f"[ERROR] Flag {endRowOrFlag} does not exist!")
                     return []
             df = self.data.iloc[startRowOrFlag:endRowOrFlag].copy()
             if len(df)>1:
@@ -589,7 +592,7 @@ class dataHandler():
             df = self.roundDataFrame(df)
             return df
         else:
-            print(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
+            logging.error(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
             return []
 
 profile = profile()
